@@ -932,10 +932,11 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
         g_datalist_foreach((GData**)&def->backend_settings.passthrough, write_fallback_key_value, kf);
     }
 
+    g_autofree char* escaped_netdef_id = g_uri_escape_string(def->id, NULL, TRUE);
     if (ap) {
         g_autofree char* escaped_ssid = g_uri_escape_string(ap->ssid, NULL, TRUE);
         /* TODO: make use of netplan_netdef_get_output_filename() */
-        conf_path = g_strjoin(NULL, "run/NetworkManager/system-connections/netplan-", def->id, "-", escaped_ssid, ".nmconnection", NULL);
+        conf_path = g_strjoin(NULL, "run/NetworkManager/system-connections/netplan-", escaped_netdef_id, "-", escaped_ssid, ".nmconnection", NULL);
 
         g_key_file_set_string(kf, "wifi", "ssid", ap->ssid);
         if (ap->mode < NETPLAN_WIFI_MODE_OTHER)
@@ -970,7 +971,7 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
         }
     } else {
         /* TODO: make use of netplan_netdef_get_output_filename() */
-        conf_path = g_strjoin(NULL, "run/NetworkManager/system-connections/netplan-", def->id, ".nmconnection", NULL);
+        conf_path = g_strjoin(NULL, "run/NetworkManager/system-connections/netplan-", escaped_netdef_id, ".nmconnection", NULL);
         if (def->has_auth) {
             write_dot1x_auth_parameters(&def->auth, kf);
         }
@@ -1082,28 +1083,30 @@ netplan_state_finish_nm_write(
         GString *tmp = NULL;
         guint unmanaged = nd->backend == NETPLAN_BACKEND_NM ? 0 : 1;
 
+        g_autofree char* netdef_id = _netplan_scrub_string(nd->id);
         /* Special case: manage or ignore any device of given type on empty "match: {}" stanza */
         if (nd->has_match && !nd->match.driver && !nd->match.mac && !nd->match.original_name) {
             nm_type = type_str(nd);
             g_assert(nm_type);
             g_string_append_printf(nm_conf, "[device-netplan.%s.%s]\nmatch-device=type:%s\n"
                                             "managed=%d\n\n", netplan_def_type_name(nd->type),
-                                            nd->id, nm_type, !unmanaged);
+                                            netdef_id, nm_type, !unmanaged);
         }
         /* Normal case: manage or ignore devices by specific udev rules */
         else {
             const gchar *prefix = "SUBSYSTEM==\"net\", ACTION==\"add|change|move\",";
             const gchar *suffix = nd->backend == NETPLAN_BACKEND_NM ? " ENV{NM_UNMANAGED}=\"0\"\n" : " ENV{NM_UNMANAGED}=\"1\"\n";
             g_string_append_printf(udev_rules, "# netplan: network.%s.%s (on NetworkManager %s)\n",
-                                   netplan_def_type_name(nd->type), nd->id,
+                                   netplan_def_type_name(nd->type), netdef_id,
                                    unmanaged ? "deny-list" : "allow-list");
             /* Match by explicit interface name, if possible */
             if (nd->set_name) {
                 // simple case: explicit new interface name
-                g_string_append_printf(udev_rules, "%s ENV{ID_NET_NAME}==\"%s\",%s", prefix, nd->set_name, suffix);
+                g_autofree char* set_name = _netplan_scrub_string(nd->set_name);
+                g_string_append_printf(udev_rules, "%s ENV{ID_NET_NAME}==\"%s\",%s", prefix, set_name, suffix);
             } else if (!nd->has_match) {
                 // simple case: explicit netplan ID is interface name
-                g_string_append_printf(udev_rules, "%s ENV{ID_NET_NAME}==\"%s\",%s", prefix, nd->id, suffix);
+                g_string_append_printf(udev_rules, "%s ENV{ID_NET_NAME}==\"%s\",%s", prefix, netdef_id, suffix);
             }
             /* Also, match by explicit (new) MAC, if available */
             if (nd->set_mac && _is_valid_macaddress(nd->set_mac)) {
@@ -1119,9 +1122,10 @@ netplan_state_finish_nm_write(
                 // match on original name glob
                 // TODO: maybe support matching on multiple name globs in the future (like drivers)
                 g_string_append(udev_rules, prefix);
-                if (nd->match.original_name)
-                    g_string_append_printf(udev_rules, " ENV{ID_NET_NAME}==\"%s\",", nd->match.original_name);
-
+                if (nd->match.original_name) {
+                    g_autofree char* original_name = _netplan_scrub_string(nd->match.original_name);
+                    g_string_append_printf(udev_rules, " ENV{ID_NET_NAME}==\"%s\",", original_name);
+                }
                 // match on (explicit) MAC address. Yes this would be unique on its own, but we
                 // keep it within the "full match" to make the logic more comprehensible.
                 if (nd->match.mac) {
@@ -1139,7 +1143,9 @@ netplan_state_finish_nm_write(
                         g_strfreev(split);
                     } else
                         drivers = g_strdup(nd->match.driver);
-                    g_string_append_printf(udev_rules, " ENV{ID_NET_DRIVER}==\"%s\",", drivers);
+
+                    g_autofree char* escaped_drivers = _netplan_scrub_string(drivers);
+                    g_string_append_printf(udev_rules, " ENV{ID_NET_DRIVER}==\"%s\",", escaped_drivers);
                     g_free(drivers);
                 }
                 g_string_append(udev_rules, suffix);
@@ -1150,13 +1156,13 @@ netplan_state_finish_nm_write(
 
     /* write generated NetworkManager drop-in config */
     if (nm_conf->len > 0)
-        _netplan_g_string_free_to_file(nm_conf, rootdir, "run/NetworkManager/conf.d/netplan.conf", NULL);
+        _netplan_g_string_free_to_file_with_permissions(nm_conf, rootdir, "run/NetworkManager/conf.d/netplan.conf", NULL, "root", "root", 0640);
     else
         g_string_free(nm_conf, TRUE);
 
     /* write generated udev rules */
     if (udev_rules->len > 0)
-        _netplan_g_string_free_to_file(udev_rules, rootdir, "run/udev/rules.d/90-netplan.rules", NULL);
+        _netplan_g_string_free_to_file_with_permissions(udev_rules, rootdir, "run/udev/rules.d/90-netplan.rules", NULL, "root", "root", 0640);
     else
         g_string_free(udev_rules, TRUE);
 
