@@ -54,7 +54,10 @@ write_sriov_rebind_systemd_unit(GHashTable* pfs, const char* rootdir, GError** e
     g_string_truncate(interfaces, interfaces->len-1); /* cut trailing whitespace */
     g_string_append_printf(s, "ExecStart=" SBINDIR "/netplan rebind --debug %s\n", interfaces->str);
 
-    _netplan_g_string_free_to_file(s, rootdir, path, NULL);
+    g_autofree char* new_s = _netplan_scrub_systemd_unit_contents(s->str);
+    g_string_free(s, TRUE);
+    s = g_string_new(new_s);
+    _netplan_g_string_free_to_file_with_permissions(s, rootdir, path, NULL, "root", "root", 0640);
     g_string_free(interfaces, TRUE);
 
     _netplan_safe_mkdir_p_dir(link);
@@ -90,7 +93,10 @@ write_sriov_apply_systemd_unit(GHashTable* pfs, const char* rootdir, GError** er
     g_string_append(s, "\n[Service]\nType=oneshot\n");
     g_string_append_printf(s, "ExecStart=" SBINDIR "/netplan apply --sriov-only\n");
 
-    _netplan_g_string_free_to_file(s, rootdir, path, NULL);
+    g_autofree char* new_s = _netplan_scrub_systemd_unit_contents(s->str);
+    g_string_free(s, TRUE);
+    s = g_string_new(new_s);
+    _netplan_g_string_free_to_file_with_permissions(s, rootdir, path, NULL, "root", "root", 0640);
 
     _netplan_safe_mkdir_p_dir(link);
     if (symlink(path, link) < 0 && errno != EEXIST) {
@@ -118,13 +124,18 @@ netplan_state_finish_sriov_write(const NetplanState* np_state, const char* rootd
         GHashTable* rebind_pfs = g_hash_table_new(g_str_hash, g_str_equal);
         GHashTable* apply_pfs = g_hash_table_new(g_str_hash, g_str_equal);
 
-        /* Find netdev interface names for SR-IOV PFs*/
+        /* Find netdev interface names for SR-IOV PFs
+         * We consider an interface to be a PF if at least of the conditions below is true:
+         * 1) the user explicitly set a desired number of VFs
+         * 2) there is at least one interface with a link to it (meaning the interface is a VF of this PF)
+         * 3) the user set the embedded-switch-mode (which can be applied regardless if the interface has VFs) 
+         * */
         for (GList* iterator = np_state->netdefs_ordered; iterator; iterator = iterator->next) {
             def = (NetplanNetDefinition*) iterator->data;
             pf = NULL;
-            if (def->sriov_explicit_vf_count < G_MAXUINT || def->sriov_link) {
+            if (def->sriov_explicit_vf_count < G_MAXUINT || def->sriov_link || def->embedded_switch_mode) {
                 any_sriov = TRUE;
-                if (def->sriov_explicit_vf_count < G_MAXUINT)
+                if (def->sriov_explicit_vf_count < G_MAXUINT || def->embedded_switch_mode)
                     pf = def;
                 else if (def->sriov_link)
                     pf = def->sriov_link;
